local LMP = LibStub("LibMediaProvider-1.0")

local METER_STATISTIC_COLOR_HEADER_BIG = "#f6b34a"
local METER_STATISTIC_COLOR_HEADER_NORMAL = "#ffffff"
local METER_STATISTIC_COLOR_NORMAL = "#b0b0b0"

isLoaded = false

local abilityLabels = {}

local lastLeftTop = 50
local lastRightTop = 50

local currentUnitData = nil
local currentTargetData = nil
local playerList = {}

local function OnMouseDown(_eventCode, _button, _ctrl, _alt, _shift)
	if _button == 1 then
		AUI_MeterStatistic:SetMovable(true)
		AUI_MeterStatistic:StartMoving()
	end
end

local function OnMouseUp(_eventCode, _button, _ctrl, _alt, _shift)
	_, AUI.Settings.Combat.detail_statistic_window_position.point, _, AUI.Settings.Combat.detail_statistic_window_position.relativePoint, AUI.Settings.Combat.detail_statistic_window_position.offsetX, AUI.Settings.Combat.detail_statistic_window_position.offsetY = AUI_MeterStatistic:GetAnchor()

	AUI_MeterStatistic:SetMovable(false)
end

local function UpdateUI(_sourceId, _type, _targetData)
	local totalString = ""
	local totalCritString = ""
	local normalDamageString = ""
	local avarageString = ""
	
	if _type == AUI_COMBAT_DATA_TYPE_DAMAGE_OUT then
		totalString = AUI.L10n.GetString("total_damage") .. ": "
		normalDamageString = AUI.L10n.GetString("damage") .. ": "
		totalCritString = AUI.L10n.GetString("critical_damage") .. ": "
		avarageString = AUI.L10n.GetString("dps") .. ": "	
	elseif _type == AUI_COMBAT_DATA_TYPE_DAMAGE_IN then
		totalString = AUI.L10n.GetString("total_damage") .. ": "
		normalDamageString = AUI.L10n.GetString("damage") .. ": "
		totalCritString = AUI.L10n.GetString("critical_damage") .. ": "
		avarageString = AUI.L10n.GetString("dps") .. ": "			
	elseif _type == AUI_COMBAT_DATA_TYPE_HEAL_OUT then
		totalString = AUI.L10n.GetString("total_healing") .. ": "
		normalDamageString = AUI.L10n.GetString("healing") .. ": "
		totalCritString = AUI.L10n.GetString("critical_healing") .. ": "
		avarageString = AUI.L10n.GetString("hps") .. ": "	
	elseif _type == AUI_COMBAT_DATA_TYPE_HEAL_IN then
		totalString = AUI.L10n.GetString("total_healing") .. ": "
		normalDamageString = AUI.L10n.GetString("healing") .. ": "
		totalCritString = AUI.L10n.GetString("critical_healing") .. ": "
		avarageString = AUI.L10n.GetString("hps") .. ": "		
	end	
	
	local totalValue = 0
	local totalCritValue = 0
	local avarageValue = 0	
	local totalAbilityList = nil
	local targetTimeMS = 0
	local endTimeMS = 0

	local unitData = _targetData
	
	if unitData then	
		totalValue = unitData.total
		normalDamageValue = unitData.damage
		totalCritValue = unitData.crit
		endTimeMS = unitData.endTimeMS
		avarageValue = AUI.Combat.CalculateDPS(totalValue, unitData.endTimeMS)
		
		totalAbilityList = AUI.Combat.GetTotalAbilityList({unitData})
	else
		if _type == AUI_COMBAT_DATA_TYPE_DAMAGE_OUT then
			local data = AUI.Combat.GetOutData(_sourceId)
			
			if data then
				unitData = data[AUI_COMBAT_DATA_TYPE_DAMAGE_OUT]
			end
		elseif _type == AUI_COMBAT_DATA_TYPE_DAMAGE_IN then
			local data  = AUI.Combat.GetInData(_sourceId)
			
			if data then
				unitData = data[AUI_COMBAT_DATA_TYPE_DAMAGE_IN]
			end			
		elseif _type == AUI_COMBAT_DATA_TYPE_HEAL_OUT then
			local data  = AUI.Combat.GetOutData(_sourceId)
			
			if data then
				unitData = data[AUI_COMBAT_DATA_TYPE_HEAL_OUT]
			end			
		elseif _type == AUI_COMBAT_DATA_TYPE_HEAL_IN then		
			local data  = AUI.Combat.GetInData(_sourceId)
			
			if data then
				unitData = data[AUI_COMBAT_DATA_TYPE_HEAL_IN]
			end			
		end
		
		if unitData then
			endTimeMS = unitData.endTimeMS
			totalValue = AUI.Combat.GetTotalValue(unitData.targets, "total")
			normalDamageValue = AUI.Combat.GetTotalValue(unitData.targets, "damage")
			totalCritValue = AUI.Combat.GetTotalValue(unitData.targets, "crit")
			avarageValue = AUI.Combat.CalculateDPS(totalValue, endTimeMS)
			totalAbilityList = AUI.Combat.GetTotalAbilityList(unitData.targets)	
		end		
	end	
	
	if totalValue == 0 then
		return
	end
	
	local endTimeS = AUI.Time.MS_To_S(endTimeMS)
	
	if totalValue > 0 then
		totalString = totalString .. AUI.String.ToFormatedNumber(totalValue) .. " (" .. AUI.Time.GetFormatedString(endTimeS, 3) .. ")"
	else
		totalString = totalString .. "-"
	end	

	if normalDamageValue > 0 then
		normalDamageString = normalDamageString .. AUI.String.ToFormatedNumber(normalDamageValue) .. " (" .. AUI.String.GetPercentString(totalValue, normalDamageValue) .. ")"
	else
		normalDamageString = normalDamageString .. "-"
	end		

	if totalCritValue > 0 then
		totalCritString = totalCritString .. AUI.String.ToFormatedNumber(totalCritValue) .. " (" .. AUI.String.GetPercentString(totalValue, totalCritValue) .. ")"
	else
		totalCritString = totalCritString .. "-"
	end		

	if avarageValue > 0 then
		avarageString = avarageString .. AUI.String.ToFormatedNumber(avarageValue) .. " (" ..  AUI.Time.GetFormatedString(endTimeS, 3) .. ")"
	else
		avarageString = avarageString .. "-"
	end	

	local itemList = {}	
	if totalAbilityList then
		for _, abilityData in pairs(totalAbilityList) do
			local avarageValue = AUI.Combat.CalculateDPS(abilityData.total, endTimeMS)
			local abilityName = AUI.String.FirstToUpper(zo_strformat(SI_UNIT_NAME, abilityData.abilityName))

			table.insert(itemList, 
			{
				[1] = 
				{
					value = abilityData.icon,
					width = 22,	
					height = 22,					
					
				}, 
				[2] = 
				{
					value = abilityName,
					sortValue = abilityName,
					type = "string",
					width = 150,	
					height = 32,											
				},							
				[3] = 
				{
					value = AUI.String.ToFormatedNumber(abilityData.total),
					sortValue = abilityData.total,
					type = "number",
					width = 84,	
					height = 32,						
				},									
				[4] = 
				{
					value = AUI.String.GetPercentString(abilityData.total, abilityData.crit),
					sortValue = abilityData.crit,
					type = "number",
					width = 84,	
					height = 32,						
				},						
				[5] = 
				{
					value = AUI.String.ToFormatedNumber(avarageValue),
					sortValue = avarageValue,
					type = "number",
					width = 84,	
					height = 32,						
				},					
				[6] = 
				{
					value = abilityData.hitCount,
					sortValue = abilityData.hitCount,
					type = "number",
					width = 40,	
					height = 32,						
				},				
			})				
		end			
	end		
		
	table.sort(itemList, 
	function(w1, w2) 
		return w1[3].sortValue > w2[3].sortValue
	end)		
		
	AUI_MeterStatistic_Inner_LabelTotal:SetText(totalString)
	AUI_MeterStatistic_Inner_LabelNormalDamage:SetText(normalDamageString)
	AUI_MeterStatistic_Inner_LabelCritTotal:SetText(totalCritString)
	AUI_MeterStatistic_Inner_LabelAvarage:SetText(avarageString)		
	AUI_MeterStatistic_Inner_ListBoxAbilities.SetItemList(itemList)
end

local function CreateUI()
	AUI_MeterStatistic:SetHandler("OnMouseDown", OnMouseDown)
	AUI_MeterStatistic:SetHandler("OnMouseUp", OnMouseUp)
	AUI_MeterStatistic:ClearAnchors()
	AUI_MeterStatistic:SetAnchor(AUI.Settings.Combat.detail_statistic_window_position.point, GUIROOT, AUI.Settings.Combat.detail_statistic_window_position.relativePoint, AUI.Settings.Combat.detail_statistic_window_position.offsetX, AUI.Settings.Combat.detail_statistic_window_position.offsetY)	
		
	AUI_MeterStatistic_Inner_LabelHeader:SetFont(LMP:Fetch('font', "Univers 67") .. "|" .. 24 .. "|" .. "thick-outline")
	AUI_MeterStatistic_Inner_LabelHeader:SetText("AUI - " .. AUI.L10n.GetString("meter_statistic"))
	AUI_MeterStatistic_Inner_LabelHeader:SetColor(AUI.Color.ConvertHexToRGBA(METER_STATISTIC_COLOR_HEADER_BIG, 1):UnpackRGBA())	

	AUI_MeterStatistic_Inner_LabelPlayerSelection:SetFont(LMP:Fetch('font', "Univers 67") .. "|" .. 16 .. "|" .. "outline")
	AUI_MeterStatistic_Inner_LabelPlayerSelection:SetText(AUI.L10n.GetString("source"))
	AUI_MeterStatistic_Inner_LabelPlayerSelection:SetColor(AUI.Color.ConvertHexToRGBA(METER_STATISTIC_COLOR_HEADER_NORMAL, 1):UnpackRGBA())			
		
	AUI_MeterStatistic_Inner_LabelViewModeSelection:SetFont(LMP:Fetch('font', "Univers 67") .. "|" .. 16 .. "|" .. "outline")
	AUI_MeterStatistic_Inner_LabelViewModeSelection:SetText(AUI.L10n.GetString("type"))
	AUI_MeterStatistic_Inner_LabelViewModeSelection:SetColor(AUI.Color.ConvertHexToRGBA(METER_STATISTIC_COLOR_HEADER_NORMAL, 1):UnpackRGBA())		
	
	AUI_MeterStatistic_Inner_LabelTargetSelection:SetFont(LMP:Fetch('font', "Univers 67") .. "|" .. 16 .. "|" .. "outline")
	AUI_MeterStatistic_Inner_LabelTargetSelection:SetText(AUI.L10n.GetString("target"))
	AUI_MeterStatistic_Inner_LabelTargetSelection:SetColor(AUI.Color.ConvertHexToRGBA(METER_STATISTIC_COLOR_HEADER_NORMAL, 1):UnpackRGBA())			
	
	AUI_MeterStatistic_Inner_ComboBoxPlayerSelection.dropdown = ZO_ComboBox_ObjectFromContainer(AUI_MeterStatistic_Inner_ComboBoxPlayerSelection)
	local itemPlayerNone = AUI_MeterStatistic_Inner_ComboBoxPlayerSelection.dropdown:CreateItemEntry("-", nil)
	AUI_MeterStatistic_Inner_ComboBoxPlayerSelection.dropdown:AddItem(itemPlayerNone, ZO_COMBOBOX_SUPRESS_UPDATE)	
	
	AUI_MeterStatistic_Inner_ComboBoxTypeSelection.dropdown = ZO_ComboBox_ObjectFromContainer(AUI_MeterStatistic_Inner_ComboBoxTypeSelection)
	local itemDamageOut = AUI_MeterStatistic_Inner_ComboBoxTypeSelection.dropdown:CreateItemEntry("-", nil)
	AUI_MeterStatistic_Inner_ComboBoxTypeSelection.dropdown:AddItem(itemDamageOut, ZO_COMBOBOX_SUPRESS_UPDATE)	

	AUI_MeterStatistic_Inner_ComboBoxTargetSelection.dropdown = ZO_ComboBox_ObjectFromContainer(AUI_MeterStatistic_Inner_ComboBoxTargetSelection)	
	local itemTargetNone = AUI_MeterStatistic_Inner_ComboBoxPlayerSelection.dropdown:CreateItemEntry("-", nil)	
	AUI_MeterStatistic_Inner_ComboBoxTargetSelection.dropdown:AddItem(itemTargetNone, ZO_COMBOBOX_SUPRESS_UPDATE)	
	
	AUI_MeterStatistic_Inner_LabelTotal:SetFont(LMP:Fetch('font', "Univers 67") .. "|" .. 16 .. "|" .. "outline")
	AUI_MeterStatistic_Inner_LabelTotal:SetColor(AUI.Color.ConvertHexToRGBA(METER_STATISTIC_COLOR_NORMAL, 1):UnpackRGBA())
	
	AUI_MeterStatistic_Inner_LabelNormalDamage:SetFont(LMP:Fetch('font', "Univers 67") .. "|" .. 16 .. "|" .. "outline")
	AUI_MeterStatistic_Inner_LabelNormalDamage:SetColor(AUI.Color.ConvertHexToRGBA(METER_STATISTIC_COLOR_NORMAL, 1):UnpackRGBA())		
	
	AUI_MeterStatistic_Inner_LabelCritTotal:SetFont(LMP:Fetch('font', "Univers 67") .. "|" .. 16 .. "|" .. "outline")
	AUI_MeterStatistic_Inner_LabelCritTotal:SetColor(AUI.Color.ConvertHexToRGBA(METER_STATISTIC_COLOR_NORMAL, 1):UnpackRGBA())	
	
	AUI_MeterStatistic_Inner_LabelAvarage:SetFont(LMP:Fetch('font', "Univers 67") .. "|" .. 16 .. "|" .. "outline")
	AUI_MeterStatistic_Inner_LabelAvarage:SetColor(AUI.Color.ConvertHexToRGBA(METER_STATISTIC_COLOR_NORMAL, 1):UnpackRGBA())		
	
	local columnList = {
		[1] = 	
		{
			["Name"] = "Icon",
			["Text"] = "*",
			["Width"] = 22,	
			["Height"] = 22,
			["AllowSort"] = false,
		},
		[2] = 	
		{
			["Name"] = "Name",
			["Text"] = AUI.L10n.GetString("ability"),
			["Width"] = 150,	
			["Height"] = 32,	
			["AllowSort"] = true,
		},
		[3] = 	
		{
			["Name"] = "Total",
			["Text"] = AUI.L10n.GetString("total"),
			["Width"] = 84,	
			["Height"] = 32,
			["AllowSort"] = true,
		},
		[4] = 	
		{
			["Name"] = "Crit",
			["Text"] = AUI.L10n.GetString("crit"),
			["Width"] = 84,	
			["Height"] = 32,
			["AllowSort"] = true,
		},
		[5] = 	
		{
			["Name"] = "Average",
			["Text"] =  "DPS/HPS",
			["Width"] = 84,
			["Height"] = 32,
			["AllowSort"] = true,
		},
		[6] = 	
		{
			["Name"] = "Hits",
			["Text"] =  "#",
			["Width"] = 40,
			["Height"] = 32,	
			["AllowSort"] = true,
		}		
	}
	
	local listBox_abilities = AUI.CreateListBox("AUI_MeterStatistic_Inner_ListBoxAbilities", AUI_MeterStatistic, columnList, "ListBoxRow", "ZoFontGameBold")
	listBox_abilities:SetAnchor(TOPLEFT, AUI_MeterStatistic, TOPLEFT, 24, 250)
	listBox_abilities:SetDimensions(560, 130)
	
	AUI_MeterStatistic_Inner_CloseButton:SetNormalTexture("ESOUI/art/buttons/decline_up.dds")
	AUI_MeterStatistic_Inner_CloseButton:SetPressedTexture("ESOUI/art/buttons/decline_down.dds")
	AUI_MeterStatistic_Inner_CloseButton:SetMouseOverTexture("ESOUI/art/buttons/decline_over.dds")
	AUI_MeterStatistic_Inner_CloseButton:SetHandler("OnClicked", AUI.Combat.Statistics.Hide)	
	
	AUI_MeterStatistic_Inner_ButtonPostCombatStatic:SetAnchor(CENTER, AUI_MeterStatistic, BOTTOM, 0, -24)
	AUI_MeterStatistic_Inner_ButtonPostCombatStatic:SetDimensions(200, 30)	
	AUI_MeterStatistic_Inner_ButtonPostCombatStatic:SetHandler("OnClicked", function() AUI.Combat.PostCombatStatistics(currentUnitData, currentSelectedViewMode, currentTargetData) end)
	
	AUI_MeterStatistic_Inner_ButtonPostCombatStatic_Text:SetFont(LMP:Fetch('font', "Univers 67") .. "|" .. 16 .. "|" .. "outline")
	AUI_MeterStatistic_Inner_ButtonPostCombatStatic_Text:SetText(AUI.L10n.GetString("post_in_chat"))
	AUI_MeterStatistic_Inner_ButtonPostCombatStatic_Text:SetColor(AUI.Color.ConvertHexToRGBA(METER_STATISTIC_COLOR_HEADER_NORMAL, 1):UnpackRGBA())		
end

local function SortNameList(list1, list2)
	if list1[AUI_COMBAT_DATA_TYPE_DAMAGE_OUT] and list2[AUI_COMBAT_DATA_TYPE_DAMAGE_OUT] then
		if list1[AUI_COMBAT_DATA_TYPE_DAMAGE_OUT].total > list2[AUI_COMBAT_DATA_TYPE_DAMAGE_OUT].total then
			return true
		end
	end
end

local function SortTargetList(list1, list2)
	if list1.total > list2.total then
		return true
	end	
end

local function UpdateTargetData(_sourceId, _data, _type)
	AUI_MeterStatistic_Inner_ComboBoxTargetSelection.dropdown:ClearItems()	
	
	local mainTargetItem = AUI_MeterStatistic_Inner_ComboBoxTargetSelection.dropdown:CreateItemEntry(AUI.L10n.GetString("all"),
	function(choice, choiceText) 
		currentTargetData = nil
		UpdateUI(_sourceId, _type)
	end)		
	AUI_MeterStatistic_Inner_ComboBoxTargetSelection.dropdown:AddItem(mainTargetItem, ZO_COMBOBOX_SUPRESS_UPDATE)
						
	if _data then
		local targetList = {}
		for _, unitData in pairs(_data.targets) do
			table.insert(targetList, unitData)
		end		
	
		table.sort(targetList, SortTargetList)
	
		for _, targetData in pairs(targetList) do
			if targetData then
				if AUI.Combat.Data[targetData.targetUnitId] then			
					local targetItem = AUI_MeterStatistic_Inner_ComboBoxTargetSelection.dropdown:CreateItemEntry(zo_strformat(SI_UNIT_NAME, AUI.Combat.Data[targetData.targetUnitId].unitName),	
					function(choice, choiceText)
						currentTargetData = targetData
						UpdateUI(_sourceId, _type, targetData)
					end)
					AUI_MeterStatistic_Inner_ComboBoxTargetSelection.dropdown:AddItem(targetItem, ZO_COMBOBOX_SUPRESS_UPDATE)				
				end
			end		
		end	
	end
	
	currentSelectedViewMode = _type
end

function AUI.Combat.Statistics.UpdateUI()
	if not isLoaded then
		return
	end

	if AUI.Table.HasContent(AUI.Combat.Data) then
		AUI_MeterStatistic_Inner_ComboBoxPlayerSelection.dropdown:ClearItems()

		local nameList = {}
		for _, unitData in pairs(AUI.Combat.Data) do
			if unitData.init then
				table.insert(nameList, unitData)
			end
		end
			
		table.sort(nameList, SortNameList)
			
		for _, unitData in pairs(nameList) do
			if unitData and unitData.init then
				local playerItem = AUI_MeterStatistic_Inner_ComboBoxPlayerSelection.dropdown:CreateItemEntry(unitData.unitName,	
				function(choice, choiceText)
					AUI_MeterStatistic_Inner_ComboBoxTypeSelection.dropdown:ClearItems()

					if unitData[AUI_COMBAT_DATA_TYPE_DAMAGE_OUT] and AUI.Table.HasContent(unitData[AUI_COMBAT_DATA_TYPE_DAMAGE_OUT]) then
						local itemDamageOut = AUI_MeterStatistic_Inner_ComboBoxTypeSelection.dropdown:CreateItemEntry(AUI.L10n.GetString("damage") .. " (" .. AUI.L10n.GetString("outgoing") .. ")", 
						function() 
							UpdateTargetData(unitData.sourceUnitId, unitData[AUI_COMBAT_DATA_TYPE_DAMAGE_OUT], AUI_COMBAT_DATA_TYPE_DAMAGE_OUT)
							
							AUI_MeterStatistic_Inner_ComboBoxTargetSelection.dropdown:SelectItemByIndex(1)	
						end)						
						AUI_MeterStatistic_Inner_ComboBoxTypeSelection.dropdown:AddItem(itemDamageOut, ZO_COMBOBOX_SUPRESS_UPDATE)
					end
					
					if unitData[AUI_COMBAT_DATA_TYPE_HEAL_OUT] and AUI.Table.HasContent(unitData[AUI_COMBAT_DATA_TYPE_HEAL_OUT]) then
						local itemDamageOut = AUI_MeterStatistic_Inner_ComboBoxTypeSelection.dropdown:CreateItemEntry(AUI.L10n.GetString("healing") .. " (" .. AUI.L10n.GetString("outgoing") .. ")", 
						function() 
							UpdateTargetData(unitData.sourceUnitId, unitData[AUI_COMBAT_DATA_TYPE_HEAL_OUT], AUI_COMBAT_DATA_TYPE_HEAL_OUT)
							
							AUI_MeterStatistic_Inner_ComboBoxTargetSelection.dropdown:SelectItemByIndex(1)	
						end)						
						AUI_MeterStatistic_Inner_ComboBoxTypeSelection.dropdown:AddItem(itemDamageOut, ZO_COMBOBOX_SUPRESS_UPDATE)
					end
					
					local damageInData = AUI.Combat.GetInData(unitData.sourceUnitId, AUI_COMBAT_DATA_TYPE_DAMAGE_IN)
					if damageInData and damageInData[AUI_COMBAT_DATA_TYPE_DAMAGE_IN] then
						if AUI.Table.HasContent(damageInData[AUI_COMBAT_DATA_TYPE_DAMAGE_IN].targets) then
							local itemDamageIn = AUI_MeterStatistic_Inner_ComboBoxTypeSelection.dropdown:CreateItemEntry(AUI.L10n.GetString("damage") .. " (" .. AUI.L10n.GetString("incoming") .. ")", 
							function() 
								UpdateTargetData(unitData.sourceUnitId, damageInData[AUI_COMBAT_DATA_TYPE_DAMAGE_IN], AUI_COMBAT_DATA_TYPE_DAMAGE_IN)

								AUI_MeterStatistic_Inner_ComboBoxTargetSelection.dropdown:SelectItemByIndex(1)	
							end)						
							AUI_MeterStatistic_Inner_ComboBoxTypeSelection.dropdown:AddItem(itemDamageIn, ZO_COMBOBOX_SUPRESS_UPDATE)	
						end
					end						
					
					local healInData = AUI.Combat.GetInData(unitData.sourceUnitId, AUI_COMBAT_DATA_TYPE_HEAL_IN)
					if healInData and healInData[AUI_COMBAT_DATA_TYPE_HEAL_IN] then
						if AUI.Table.HasContent(healInData[AUI_COMBAT_DATA_TYPE_HEAL_IN].targets) then
							local itemDamageIn = AUI_MeterStatistic_Inner_ComboBoxTypeSelection.dropdown:CreateItemEntry(AUI.L10n.GetString("healing") .. " (" .. AUI.L10n.GetString("incoming") .. ")", 
							function() 
								UpdateTargetData(unitData.sourceUnitId, healInData[AUI_COMBAT_DATA_TYPE_HEAL_IN], AUI_COMBAT_DATA_TYPE_HEAL_IN)

								AUI_MeterStatistic_Inner_ComboBoxTargetSelection.dropdown:SelectItemByIndex(1)	
							end)						
							AUI_MeterStatistic_Inner_ComboBoxTypeSelection.dropdown:AddItem(itemDamageIn, ZO_COMBOBOX_SUPRESS_UPDATE)	
						end
					end		

					currentUnitData = unitData
					
					AUI_MeterStatistic_Inner_ComboBoxTypeSelection.dropdown:SelectItemByIndex(1)
					AUI_MeterStatistic_Inner_ComboBoxTargetSelection.dropdown:SelectItemByIndex(1)													
				end)
				AUI_MeterStatistic_Inner_ComboBoxPlayerSelection.dropdown:AddItem(playerItem, ZO_COMBOBOX_SUPRESS_UPDATE)
			end
		end	
	end

	AUI_MeterStatistic_Inner_ComboBoxPlayerSelection.dropdown:SelectItemByIndex(1)	
	AUI_MeterStatistic_Inner_ComboBoxTypeSelection.dropdown:SelectItemByIndex(1)
	AUI_MeterStatistic_Inner_ComboBoxTargetSelection.dropdown:SelectItemByIndex(1)		
end

function AUI.Combat.Statistics.IsShow()
	return not AUI_MeterStatistic:IsHidden()
end

function AUI.Combat.Statistics.Show()
	AUI_MeterStatistic:SetHidden(false)
	AUI.Combat.Statistics.UpdateUI()
end

function AUI.Combat.Statistics.Hide()
	AUI_MeterStatistic:SetHidden(true)
end

function AUI.Combat.Statistics.Toggle()
	if AUI.Combat.IsEnabled() then
		if AUI.Combat.Statistics.IsShow() then
			AUI.Combat.Statistics.Hide()
		else
			AUI.Combat.Statistics.Show()
		end
	end
end

function AUI.Combat.Statistics.Load()
	if isLoaded then
		return
	end

	isLoaded = true	

	CreateUI()
end